Learn R Programming

traj (version 1.0)

plotBoxplotTraj: Plot Boxplot of traj Object

Description

Produce a boxplot of the values of the trajectories from each cluster at every time points.

Usage

plotBoxplotTraj(x, clust.num = NULL,  ...)

Arguments

x
traj object.
clust.num
Integer indicating the cluster number to plot.NULL to print all clusters. Defaults to NULL.
...
Arguments to be passed to plot.

Details

The function plots a boxplot of values of the trajectories in a cluster at each time point.

See Also

boxplot

Examples

Run this code
# Setup data and time
data = example.data$data
time = example.data$time

# Run step1measures, step2factors and step3clusters with
# a predetermined number of clusters
s1 = step1measures(data,time, ID=TRUE)
s2 = step2factors(s1)
s3.4clusters = step3clusters(s2, nclust = 4)

# Plot boxplots
plotBoxplotTraj(s3.4clusters)

Run the code above in your browser using DataLab