| trajMeasures | R Documentation |
trajMeasures computes up to 20 measures for each
longitudinal trajectory. See Details for the list of measures.
trajMeasures(
Data,
Time = NULL,
ID = FALSE,
measures = c(1:10, 12:20),
midpoint = NULL,
cap.outliers = FALSE
)
## S3 method for class 'trajMeasures'
print(x, ...)
## S3 method for class 'trajMeasures'
summary(object, ...)
Data |
a matrix or data frame in which each row contains the longitudinal data (trajectories). |
Time |
either |
ID |
logical. Set to |
measures |
a vector containing the numerical identifiers of the measures to compute. The default, c(1:10,12:20), excludes the measure which require specifying a midpoint. |
midpoint |
specifies which column of |
cap.outliers |
logical. If |
x |
object of class |
... |
further arguments passed to or from other methods. |
object |
object of class |
Each trajectory must have a minimum of 3 observations, otherwise it is omitted from the analysis. The 20 measures and their numerical identifiers are listed below. Please refer to the vignette for the specific formulas used to compute them.
Maximum
Minimum
Range
Mean value
Standard deviation
Slope of the affine approximation
Intercept of the affine approximation
Proportion of variance explained by the affine approximation
Rate of intersection with the best affine approximation
Net variation per unit of time
Late variation to early variation contrast
Total variation per unit time
Spikiness
Maximum of the first derivative
Minimum of the first derivative
Standard deviation of the first derivative
First derivative's net variation per unit of time
Maximum of the second derivative
Minimum of the second derivative
Standard deviation of the second derivative
If 'cap.outliers' is set to TRUE, Nishiyama's improved Chebychev bound for continuous distributions
is used to determine extreme values for each measure, corresponding to
a 0.3% probability threshold. Extreme values beyond the threshold are then capped
to the 0.3% probability threshold (see vignette for more details).
An object of class trajMeasures; a list containing the values
of the measures, a table of the outliers which have been capped, as well as
a curated form of the function's arguments.
Leffondre K, Abrahamowicz M, Regeasse A, Hawker GA, Badley EM, McCusker J, Belzile E. Statistical measures were proposed for identifying longitudinal patterns of change in quantitative health indicators. J Clin Epidemiol. 2004 Oct;57(10):1049-62. doi: 10.1016/j.jclinepi.2004.02.012. PMID: 15528056.
Nishiyama T, Improved Chebyshev inequality: new probability bounds with known supremum of PDF, arXiv:1808.10770v2 stat.ME https://doi.org/10.48550/arXiv.1808.10770
## Not run:
data("trajdata")
trajdata.noGrp <- trajdata[, -which(colnames(trajdata) == "Group")] #remove the Group column
m1 = trajMeasures(trajdata.noGrp, ID = TRUE, measures = 19, midpoint = NULL)
m2 = trajMeasures(trajdata.noGrp, ID = TRUE, measures = 19, midpoint = 3)
identical(m1$measures, m2$measures)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.