Learn R Programming

traj (version 1.0)

example.data: Example Data

Description

Example data used to display the features of the traj package.

Usage

example.data

Arguments

format

List of 2 data.frames: $ data: 130 subjects with 7 variables. X1 to X6 correspond to the 6 measurements obtained on the 130 subjects: ID: num [1:130] X1: num [1:130] X2: num [1:130] X3: num [1:130] X4: num [1:130] X5: num [1:130] X6: num [1:130] $ time: 130 subjects with 7 variables. time1 to time6 correspond to the measurement times for the vairbales X1 to X6: ID : num [1:130] time1: num [1:130] time2: num [1:130] time3: num [1:130] time4: num [1:130] time5: num [1:130] time6: num [1:130]

Examples

Run this code
# data and time
data = example.data$data
time = example.data$time

Run the code above in your browser using DataLab