- Measures
object of class trajMeasures as returned by the function
trajMeasures().
- select
an optional vector of positive integers corresponding to the
measures to use in the clustering. Defaults to NULL, which uses all the measures contained in Measures.
- fuzzy
logical. If FALSE, each trajectory is assigned to a unique group. If TRUE, each trajectory is assigned a "degree of membership" to each group. Defaults to FALSE.
- nclusters
The desired number of clusters. If NULL, clustering is carried out for every number of clusters between 2 and (up to) 8 and the "best" number of clusters is used, as judged by the combination of three internal cluster validity indices. See section 'Value' for more details. Defaults to NULL.
- subset.n
A positive numerical integer smaller than the number of trajectories. If nclusters is NULL, subset is the number of trajectories, randomly sampled from the complete data set, that will be used to determine the optimal number of clusters in the interest of speeding up the process.
- nstart
The number of random starts. Defaults to 50.
- x
object of class trajClusters.
- ...
further arguments passed to or from other methods.
- object
object of class trajClusters.
- top_p
The top_p most discriminating measures for each cluster to be reported in the summary.